@@ -1,4 +1,3 @@
-#![allow(clippy::integer_arithmetic)]
 #![cfg(feature = "full")]
 
 use crate::instruction::Instruction;
@@ -16,6 +15,7 @@ pub enum Secp256k1Error {
 pub const HASHED_PUBKEY_SERIALIZED_SIZE: usize = 20;
 pub const SIGNATURE_SERIALIZED_SIZE: usize = 64;
 pub const SIGNATURE_OFFSETS_SERIALIZED_SIZE: usize = 11;
+pub const DATA_START: usize = SIGNATURE_OFFSETS_SERIALIZED_SIZE + 1;
 
 #[derive(Default, Serialize, Deserialize, Debug)]
 pub struct SecpSignatureOffsets {
@@ -29,38 +29,44 @@ pub struct SecpSignatureOffsets {
 }
 
 pub fn new_secp256k1_instruction(
-    priv_key: &libsecp256k1::SecretKey,
+    priv_key: &secp256k1::SecretKey,
     message_arr: &[u8],
 ) -> Instruction {
-    let secp_pubkey = libsecp256k1::PublicKey::from_secret_key(priv_key);
+    let secp_pubkey = secp256k1::PublicKey::from_secret_key(priv_key);
     let eth_pubkey = construct_eth_pubkey(&secp_pubkey);
     let mut hasher = sha3::Keccak256::new();
     hasher.update(&message_arr);
     let message_hash = hasher.finalize();
     let mut message_hash_arr = [0u8; 32];
     message_hash_arr.copy_from_slice(&message_hash.as_slice());
-    let message = libsecp256k1::Message::parse(&message_hash_arr);
-    let (signature, recovery_id) = libsecp256k1::sign(&message, priv_key);
+    let message = secp256k1::Message::parse(&message_hash_arr);
+    let (signature, recovery_id) = secp256k1::sign(&message, priv_key);
     let signature_arr = signature.serialize();
     assert_eq!(signature_arr.len(), SIGNATURE_SERIALIZED_SIZE);
 
     let mut instruction_data = vec![];
-    let data_start = 1 + SIGNATURE_OFFSETS_SERIALIZED_SIZE;
     instruction_data.resize(
-        data_start + eth_pubkey.len() + signature_arr.len() + message_arr.len() + 1,
+        DATA_START
+            .saturating_add(eth_pubkey.len())
+            .saturating_add(signature_arr.len())
+            .saturating_add(message_arr.len())
+            .saturating_add(1),
         0,
     );
-    let eth_address_offset = data_start;
-    instruction_data[eth_address_offset..eth_address_offset + eth_pubkey.len()]
+    let eth_address_offset = DATA_START;
+    instruction_data[eth_address_offset..eth_address_offset.saturating_add(eth_pubkey.len())]
         .copy_from_slice(&eth_pubkey);
 
-    let signature_offset = data_start + eth_pubkey.len();
-    instruction_data[signature_offset..signature_offset + signature_arr.len()]
+    let signature_offset = DATA_START.saturating_add(eth_pubkey.len());
+    instruction_data[signature_offset..signature_offset.saturating_add(signature_arr.len())]
         .copy_from_slice(&signature_arr);
 
-    instruction_data[signature_offset + signature_arr.len()] = recovery_id.serialize();
+    instruction_data[signature_offset.saturating_add(signature_arr.len())] =
+        recovery_id.serialize();
 
-    let message_data_offset = signature_offset + signature_arr.len() + 1;
+    let message_data_offset = signature_offset
+        .saturating_add(signature_arr.len())
+        .saturating_add(1);
     instruction_data[message_data_offset..].copy_from_slice(message_arr);
 
     let num_signatures = 1;
@@ -74,7 +80,7 @@ pub fn new_secp256k1_instruction(
         message_data_size: message_arr.len() as u16,
         message_instruction_index: 0,
     };
-    let writer = std::io::Cursor::new(&mut instruction_data[1..data_start]);
+    let writer = std::io::Cursor::new(&mut instruction_data[1..DATA_START]);
     bincode::serialize_into(writer, &offsets).unwrap();
 
     Instruction {
@@ -84,9 +90,7 @@ pub fn new_secp256k1_instruction(
     }
 }
 
-pub fn construct_eth_pubkey(
-    pubkey: &libsecp256k1::PublicKey,
-) -> [u8; HASHED_PUBKEY_SERIALIZED_SIZE] {
+pub fn construct_eth_pubkey(pubkey: &secp256k1::PublicKey) -> [u8; HASHED_PUBKEY_SERIALIZED_SIZE] {
     let mut addr = [0u8; HASHED_PUBKEY_SERIALIZED_SIZE];
     addr.copy_from_slice(&sha3::Keccak256::digest(&pubkey.serialize()[1..])[12..]);
     assert_eq!(addr.len(), HASHED_PUBKEY_SERIALIZED_SIZE);
@@ -96,19 +100,22 @@ pub fn construct_eth_pubkey(
 pub fn verify_eth_addresses(
     data: &[u8],
     instruction_datas: &[&[u8]],
-    libsecp256k1_0_5_upgrade_enabled: bool,
 ) -> Result<(), Secp256k1Error> {
     if data.is_empty() {
         return Err(Secp256k1Error::InvalidInstructionDataSize);
     }
     let count = data[0] as usize;
-    let expected_data_size = 1 + count * SIGNATURE_OFFSETS_SERIALIZED_SIZE;
+    let expected_data_size = count
+        .saturating_mul(SIGNATURE_OFFSETS_SERIALIZED_SIZE)
+        .saturating_add(1);
     if data.len() < expected_data_size {
         return Err(Secp256k1Error::InvalidInstructionDataSize);
     }
     for i in 0..count {
-        let start = 1 + i * SIGNATURE_OFFSETS_SERIALIZED_SIZE;
-        let end = start + SIGNATURE_OFFSETS_SERIALIZED_SIZE;
+        let start = i
+            .saturating_mul(SIGNATURE_OFFSETS_SERIALIZED_SIZE)
+            .saturating_add(1);
+        let end = start.saturating_add(SIGNATURE_OFFSETS_SERIALIZED_SIZE);
 
         let offsets: SecpSignatureOffsets = bincode::deserialize(&data[start..end])
             .map_err(|_| Secp256k1Error::InvalidSignature)?;
@@ -120,24 +127,15 @@ pub fn verify_eth_addresses(
         }
         let signature_instruction = instruction_datas[signature_index];
         let sig_start = offsets.signature_offset as usize;
-        let sig_end = sig_start + SIGNATURE_SERIALIZED_SIZE;
+        let sig_end = sig_start.saturating_add(SIGNATURE_SERIALIZED_SIZE);
         if sig_end >= signature_instruction.len() {
             return Err(Secp256k1Error::InvalidSignature);
         }
+        let signature =
+            secp256k1::Signature::parse_slice(&signature_instruction[sig_start..sig_end])
+                .map_err(|_| Secp256k1Error::InvalidSignature)?;
 
-        let sig_parse_result = if libsecp256k1_0_5_upgrade_enabled {
-            libsecp256k1::Signature::parse_standard_slice(
-                &signature_instruction[sig_start..sig_end],
-            )
-        } else {
-            libsecp256k1::Signature::parse_overflowing_slice(
-                &signature_instruction[sig_start..sig_end],
-            )
-        };
-
-        let signature = sig_parse_result.map_err(|_| Secp256k1Error::InvalidSignature)?;
-
-        let recovery_id = libsecp256k1::RecoveryId::parse(signature_instruction[sig_end])
+        let recovery_id = secp256k1::RecoveryId::parse(signature_instruction[sig_end])
             .map_err(|_| Secp256k1Error::InvalidRecoveryId)?;
 
         // Parse out pubkey
@@ -160,8 +158,8 @@ pub fn verify_eth_addresses(
         hasher.update(message_slice);
         let message_hash = hasher.finalize();
 
-        let pubkey = libsecp256k1::recover(
-            &libsecp256k1::Message::parse_slice(&message_hash).unwrap(),
+        let pubkey = secp256k1::recover(
+            &secp256k1::Message::parse_slice(&message_hash).unwrap(),
             &signature,
             &recovery_id,
         )
@@ -187,7 +185,7 @@ fn get_data_slice<'a>(
     }
     let signature_instruction = &instruction_datas[signature_index];
     let start = offset_start as usize;
-    let end = start + size;
+    let end = start.saturating_add(size);
     if end > signature_instruction.len() {
         return Err(Secp256k1Error::InvalidSignature);
     }
@@ -200,19 +198,19 @@ pub mod test {
     use super::*;
 
     fn test_case(num_signatures: u8, offsets: &SecpSignatureOffsets) -> Result<(), Secp256k1Error> {
-        let mut instruction_data = vec![0u8; 1 + SIGNATURE_OFFSETS_SERIALIZED_SIZE];
+        let mut instruction_data = vec![0u8; DATA_START];
         instruction_data[0] = num_signatures;
         let writer = std::io::Cursor::new(&mut instruction_data[1..]);
         bincode::serialize_into(writer, &offsets).unwrap();
 
-        verify_eth_addresses(&instruction_data, &[&[0u8; 100]], false)
+        verify_eth_addresses(&instruction_data, &[&[0u8; 100]])
     }
 
     #[test]
     fn test_invalid_offsets() {
         solana_logger::setup();
 
-        let mut instruction_data = vec![0u8; 1 + SIGNATURE_OFFSETS_SERIALIZED_SIZE];
+        let mut instruction_data = vec![0u8; DATA_START];
         let offsets = SecpSignatureOffsets::default();
         instruction_data[0] = 1;
         let writer = std::io::Cursor::new(&mut instruction_data[1..]);
@@ -220,7 +218,7 @@ pub mod test {
         instruction_data.truncate(instruction_data.len() - 1);
 
         assert_eq!(
-            verify_eth_addresses(&instruction_data, &[&[0u8; 100]], false),
+            verify_eth_addresses(&instruction_data, &[&[0u8; 100]]),
             Err(Secp256k1Error::InvalidInstructionDataSize)
         );
 
